@@ -16,6 +16,7 @@ from loguru import logger
 from rich.console import Console
 from rich.table import Table
 from types import FunctionType
+from threading import Thread
 
 
 this_dir, this_filename = os.path.split(__file__)
@@ -47,20 +48,19 @@ class HaimgardShell(cmd.Cmd):
 
         self.options = {
             "target": {"value": None, "required": True},
-            "amount": {"value": 1000, "required": True},
-            "ssl": {"value": "True", "required": False},
-            "sslverify": {"value": "True", "required": False},
+            "amount": {"value": 0, "required": False},
+            "ssl": {"value": "1", "required": False},
+            "sslverify": {"value": "1", "required": False},
             "port": {"value": 443, "required": False},
             "path": {"value": "", "required": False},
             "timeout": {"value": 1, "required": False},
-            "commonport": {"value": 1000, "required": False},
-            "start": {"value": 1, "required": False},
-            "end": {"value": 100, "required": False},
+            "start": {"value": 0, "required": False},
+            "end": {"value": 0, "required": False},
             "requestdelay": {"value": 0.1, "required": False},
             "pluginnumber": {"value": 100, "required": False},
             "themenumber": {"value": 100, "required": False},
-            "aggressive": {"value": "False", "required": False},
-            "update": {"value": "False", "required": False}
+            "aggressive": {"value": "0", "required": False},
+            "update": {"value": "0", "required": False}
         }        
 
     def do_mode(self, arg):
@@ -71,12 +71,10 @@ class HaimgardShell(cmd.Cmd):
 
         if arg == "passive":
             self.options["amount"]["value"] = 0
-            self.options["commonport"]["value"] = 0
             self.options["start"]["value"] = 0
             self.options["end"]["value"] = 0
         elif arg == "normal":
             self.options["amount"]["value"] = 100
-            self.options["commonport"]["value"] = 1000
             self.options["start"]["value"] = 1
             self.options["end"]["value"] = 100
         else:
@@ -122,7 +120,8 @@ class HaimgardShell(cmd.Cmd):
             )
             for option in self.options:
                 if option in self.module.options:
-                    self.module.options[option]["value"] = self.options[option]["value"]
+                    if self.module.options[option]["value"] is None:
+                        self.module.options[option]["value"] = self.options[option]["value"]
         else:
             logger.error("Module already selected")
 
@@ -145,8 +144,13 @@ class HaimgardShell(cmd.Cmd):
                     the_module = module.Module(logger)
                     for option in self.options:
                         if option in the_module.options:
-                            the_module.options[option]["value"] = self.options[option]["value"]                    
-                    the_module.run()                   
+                            if the_module.options[option]["value"] is None:
+                                the_module.options[option]["value"] = self.options[option]["value"]                     
+                    try:
+                        if the_module.runauto:
+                            Thread(target = the_module.run).start()
+                    except BaseException:
+                        logger.exception("An exception was thrown!")                
 
         if not found:
             logger.error("No module found")
@@ -171,8 +175,13 @@ class HaimgardShell(cmd.Cmd):
                                 the_module = module.Module(logger)
                                 for option in self.options:
                                     if option in the_module.options:
-                                        the_module.options[option]["value"] = self.options[option]["value"]                    
-                                the_module.run()                   
+                                        if the_module.options[option]["value"] is None:
+                                            the_module.options[option]["value"] = self.options[option]["value"]                    
+                                try:
+                                    if the_module.runauto:
+                                        Thread(target = the_module.run).start()
+                                except BaseException:
+                                    logger.exception("An exception was thrown!")                                                
 
         if not found:
             logger.error("No module found")
@@ -203,7 +212,12 @@ class HaimgardShell(cmd.Cmd):
             Console().print(table)
 
     def do_set(self, arg):
-        "set target arg"
+        "set target value"
+
+        if arg == "" or len(arg.split()) != 2:
+            logger.error("Please give a option and value")
+            return
+
         key = arg.split()[0]
         value = arg.split()[1]
         finded_option = False
@@ -224,11 +238,14 @@ class HaimgardShell(cmd.Cmd):
 
     def do_run(self,arg):
         "run"
-        try:
-            self.module.run()
-        except BaseException:
-            logger.exception("An exception was thrown!")
-        
+        if self.module is not None:
+            try:
+                self.module.run()
+            except BaseException:
+                logger.exception("An exception was thrown!")
+        else:
+            logger.error("No module found")
+            return         
 
     def do_info(self, arg):
         "info"
@@ -251,8 +268,8 @@ class HaimgardShell(cmd.Cmd):
         "exit the module"
         self.module = None
         self.prompt = "{}haimgard{} > ".format(Fore.YELLOW, Style.RESET_ALL)
-    def do_EOF(self, arg):
-        "EOF"
+    def do_eof(self, arg):
+        "eof"
         os.system("find . -name '*.pyc' -delete")
         sys.exit(1)
 
@@ -309,10 +326,11 @@ def main():
     logger.add(sys.stderr, colorize=True, format="<level>{level}: {message}</level>")
 
     start = True
+    shell = HaimgardShell()
     while True:
         try:
             if len(sys.argv) > 1 and start:
-                shell = HaimgardShell()
+                
                 arguments = ' '.join(sys.argv[1:])
 
                 method_list = [x for x, y in HaimgardShell.__dict__.items() if type(y) == FunctionType]
@@ -329,7 +347,7 @@ def main():
                     shell.onecmd(command)
                 shell.cmdloop()
             else:
-                HaimgardShell().cmdloop()
+                shell.cmdloop()
         except KeyboardInterrupt:
             print()
             logger.warning("Please use EOF or the exit/quit commands to exit")
