@@ -9,12 +9,13 @@ class Module:
         self.name = "wordpress/adminpagededection"
         self.description = "WordPress admin page detection."
         self.author = "Onur Atakan ULUSOY"
+        self.runauto = True
         self.options = {
             "target": {"value": None, "required": True},
-            "ssl": {"value": "True", "required": False},
-            "sslverify": {"value": "True", "required": False},
+            "ssl": {"value": None, "required": False},
+            "sslverify": {"value": None, "required": False},
             "port": {"value": 443, "required": False},
-            "path": {"value": "", "required": False}
+            "path": {"value": None, "required": False}
         }
 
     def info(self):
@@ -38,8 +39,8 @@ class Module:
 
 
         target = self.options["target"]["value"]
-        ssl = True if self.options["ssl"]["value"] == "True" else False
-        sslverify = True if self.options["sslverify"]["value"] == "True" else False
+        ssl = True if self.options["ssl"]["value"] == "1" else False
+        sslverify = True if self.options["sslverify"]["value"] == "1" else False
         port = int(self.options["port"]["value"])
         path = self.options["path"]["value"]
 
